all.Amidihinfusionsm<-function(){
     cat("\n")                                                                       
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Thesm_conc_input()
     cat("-----------------------------------------------------------------------\n")                                                              
     cat("\n")
     note_for_close_window()
     AmidihinfusionSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)"),
                                      value=c(0,36,176,0,0,400,24,30))
     AmidihinfusionSMMpar<-edit(AmidihinfusionSMMpar)
     
##     AmidihinfusionSMMpar<-ycheck(AmidihinfusionSMMpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------  \n")
     show(AmidihinfusionSMMpar);cat("\n\n")
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_input()
     cat("------------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihinfusionSMpar<-data.frame(ts=c(6, 12),conc=c(8.1,11.2))                                                                                                                            
     AmidihinfusionSMpar<-edit(AmidihinfusionSMpar)
     show(AmidihinfusionSMpar);cat("\n\n")                                            
     ### AmidihinfusionSMpar<-mscheck(AmidihinfusionSMpar)                                         
     cat("\n")
     Amidihinfusion.sm(length(AmidihinfusionSMpar$ts),AmidihinfusionSMpar$conc,AmidihinfusionSMpar$ts,AmidihinfusionSMMpar[3,2],AmidihinfusionSMMpar[2,2],AmidihinfusionSMMpar[5,2],AmidihinfusionSMMpar[1,2],AmidihinfusionSMMpar[4,2],AmidihinfusionSMMpar[6,2],AmidihinfusionSMMpar[8,2],AmidihinfusionSMMpar[7,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_output()
     cat("------------------------------------------------------------------------\n")
     X <- read.table("params.csv",header=FALSE)
     cl <- X[1,2]
     v  <- X[2,2]  ### 'v' is never used again.  -YJ
     ### show(samplesStats("*"))
     ### show obs. and calc. conc. here  -YJ
     ### Theinfusioncpr<-function(S,DL,R,T,tinf)
     cat("\n\n")
     for(i in 1:length(AmidihinfusionSMpar$ts)){
         Cx<-Theinfusioncpr(0.8,AmidihinfusionSMMpar[6,2],AmidihinfusionSMMpar[8,2],AmidihinfusionSMpar$ts[i],AmidihinfusionSMMpar[7,2]) 
         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(AmidihinfusionSMpar$conc[i],Cx))
         cat("--- Theophylline plasma conc. (mg/L) at Time =",AmidihinfusionSMpar$ts[i],"---\n")
         show(coutput);cat("\n")
     }
     cat("\n")
     C<-0.8*AmidihinfusionSMMpar[8,2]/(cl)
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Css_pr (mg/L)")  ### not "Ctss_pr"!  it is not trough at all.
     show(coutput)     
     cat("\n")   
     Amidihinfusion.more()                   
}